@@ -117,6 +117,7 @@ Tab::setupUi() {
   connect(ui->cbChNameCountry,             static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,                 &Tab::chapterNameCountryChanged);
   connect(ui->pbChAddName,                 &QPushButton::clicked,                                                  this,                 &Tab::addChapterName);
   connect(ui->pbChRemoveName,              &QPushButton::clicked,                                                  this,                 &Tab::removeChapterName);
+  connect(ui->pbBrowseSegmentUID,          &QPushButton::clicked,                                                  this,                 &Tab::addSegmentUIDFromFile);
 
   connect(m_expandAllAction,               &QAction::triggered,                                                    this,                 &Tab::expandAll);
   connect(m_collapseAllAction,             &QAction::triggered,                                                    this,                 &Tab::collapseAll);
@@ -174,6 +175,8 @@ Tab::retranslateUi() {
   m_generateSubChaptersAction->setText(QY("&Generate sub-chapters"));
   m_renumberSubChaptersAction->setText(QY("Re&number sub-chapters"));
 
+  Util::setToolTip(ui->pbBrowseSegmentUID, QY("Select an existing Matroska or WebM file and the GUI will add its segment UID to the input field on the left."));
+
   m_chapterModel->retranslateUi();
   m_nameModel->retranslateUi();
 
@@ -1065,8 +1068,8 @@ Tab::removeElement() {
 }
 
 void
-Tab::shiftTimecodes(QStandardItem *item,
-                    int64_t delta) {
+Tab::applyModificationToTimecodes(QStandardItem *item,
+                                  std::function<int64_t(int64_t)> const &unaryOp) {
   if (!item)
     return;
 
@@ -1077,9 +1080,9 @@ Tab::shiftTimecodes(QStandardItem *item,
       auto kEnd   = FindChild<KaxChapterTimeEnd>(*chapter);
 
       if (kStart)
-        kStart->SetValue(std::max<int64_t>(static_cast<int64_t>(kStart->GetValue()) + delta, 0));
+        kStart->SetValue(std::max<int64_t>(unaryOp(static_cast<int64_t>(kStart->GetValue())), 0));
       if (kEnd)
-        kEnd->SetValue(std::max<int64_t>(static_cast<int64_t>(kEnd->GetValue()) + delta, 0));
+        kEnd->SetValue(std::max<int64_t>(unaryOp(static_cast<int64_t>(kEnd->GetValue())), 0));
 
       if (kStart || kEnd)
         m_chapterModel->updateRow(item->index());
@@ -1087,7 +1090,19 @@ Tab::shiftTimecodes(QStandardItem *item,
   }
 
   for (auto row = 0, numRows = item->rowCount(); row < numRows; ++row)
-    shiftTimecodes(item->child(row), delta);
+    applyModificationToTimecodes(item->child(row), unaryOp);
+}
+
+void
+Tab::multiplyTimecodes(QStandardItem *item,
+                       double factor) {
+  applyModificationToTimecodes(item, [=](int64_t timecode) { return static_cast<int64_t>((timecode * factor) * 10.0 + 5) / 10ll; });
+}
+
+void
+Tab::shiftTimecodes(QStandardItem *item,
+                    int64_t delta) {
+  applyModificationToTimecodes(item, [=](int64_t timecode) { return timecode + delta; });
 }
 
 void
@@ -1224,6 +1239,9 @@ Tab::massModify() {
   if (actions & MassModificationDialog::Shift)
     shiftTimecodes(item, dlg.shiftBy());
 
+  if (actions & MassModificationDialog::Multiply)
+    multiplyTimecodes(item, dlg.multiplyBy());
+
   if (actions & MassModificationDialog::Constrict)
     constrictTimecodes(item, {}, {});
 
@@ -1258,31 +1276,7 @@ Tab::formatChapterName(QString const &nameTemplate,
                        int chapterNumber,
                        timestamp_c const &startTimecode)
   const {
-  auto name       = QString{ nameTemplate };
-  auto numberRe   = QRegularExpression{Q("<NUM(?::(\\d+))?>")};
-  auto timecodeRe = QRegularExpression{Q("<START(?::([^>]+))?>")};
-
-  while (true) {
-    auto matches = numberRe.match(name);
-    if (!matches.hasMatch())
-      break;
-
-    auto minWidth  = matches.capturedLength(1) ? matches.captured(1).toInt() : 1;
-    auto strNumber = Q("%1").arg(QString::number(chapterNumber), minWidth, '0');
-
-    name.replace(matches.capturedStart(), matches.capturedLength(), strNumber);
-  }
-
-  while (true) {
-    auto matches = timecodeRe.match(name);
-    if (!matches.hasMatch())
-      break;
-
-    auto format = matches.capturedLength(1) ? matches.captured(1) : Q("%H:%M:%S");
-    name.replace(matches.capturedStart(), matches.capturedLength(), Q(format_timestamp(startTimecode, to_utf8(format))));
-  }
-
-  return name;
+  return Q(format_chapter_name_template(to_utf8(nameTemplate), chapterNumber, startTimecode));
 }
 
 void
@@ -1641,4 +1635,9 @@ Tab::closeTab() {
   emit removeThisTab();
 }
 
+void
+Tab::addSegmentUIDFromFile() {
+  Util::addSegmentUIDFromFileToLineEdit(*this, *ui->leChSegmentUid, false);
+}
+
 }}}
